@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '1.67';
+$HTTP::BrowserDetect::VERSION = '1.69';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -10,7 +10,7 @@ our @OS_TESTS = qw(
     windows mac   os2
     unix    linux vms
     bsd     amiga firefoxos
-    rimtabletos
+    bb10    rimtabletos
 );
 
 # More precise Windows
@@ -119,6 +119,7 @@ our @ENGINE_TESTS = qw(
 # https://support.google.com/webmasters/answer/1061943?hl=en
 
 my %ROBOTS = (
+    ahrefs         => 'Ahrefs',
     altavista      => 'AltaVista',
     askjeeves      => 'AskJeeves',
     baidu          => 'Baidu Spider',
@@ -150,6 +151,7 @@ my %ROBOTS = (
     webtv          => 'WebTV',
     wget           => 'wget',
     yahoo          => 'Yahoo',
+    yandex         => 'Yandex',
     yandeximages   => 'YandexImages',
 );
 
@@ -166,6 +168,7 @@ our @ROBOT_TESTS = qw(
     askjeeves    googleadsense googlebotvideo
     googlebotnews googlebotimage google
     linkchecker  yandeximages specialarchiver
+    yandex       ahrefs
 );
 
 our @MISC_TESTS = qw(
@@ -548,6 +551,7 @@ sub _test {
     # Devices
 
     $tests->{BLACKBERRY} = ( index( $ua, "blackberry" ) != -1
+            || index( $ua, "bb10" ) != -1
             || index( $ua, "rim tablet os" ) != -1 );
     $tests->{IPHONE}   = ( index( $ua, "iphone" ) != -1 );
     $tests->{WINCE}    = ( index( $ua, "windows ce" ) != -1 );
@@ -625,6 +629,8 @@ sub _test {
             || index( $ua, "fennec" ) != -1
             || index( $ua, "opera tablet" ) != -1
             || index( $ua, "rim tablet" ) != -1
+            || ( index( $ua, "bb10" ) != -1
+            && index( $ua, "mobile" ) != -1 )
             || $tests->{PSP}
             || $tests->{DSI}
             || $tests->{'N3DS'}
@@ -726,6 +732,14 @@ sub _test {
             pos( $ua ) - length $1, length $1;
         $self->{device_name} =~ s/; / /;
     }
+    elsif ( $ua
+        =~ /bb10; ([^;\)]+)/g
+        )
+    {
+        $self->{device_name} = 'BlackBerry ' . substr $self->{user_agent},
+            pos( $ua ) - length $1, length $1;
+        $self->{device_name} =~ s/Kbd/Q10/;
+    }
 
     $self->{major} = $major;
     $self->{minor} = $minor;
@@ -755,6 +769,7 @@ sub _robot_tests {
         ) != -1
     );
 
+    $tests->{AHREFS}         = ( index( $ua, "ahrefsbot" ) != -1 );
     $tests->{ALTAVISTA}      = ( index( $ua, "altavista" ) != -1 );
     $tests->{ASKJEEVES}      = ( index( $ua, "ask jeeves/teoma" ) != -1 );
     $tests->{BAIDU}          = ( index( $ua, "baiduspider" ) != -1 );
@@ -778,10 +793,12 @@ sub _robot_tests {
     $tests->{SPECIALARCHIVER}          = ( index( $ua, "special_archiver" ) != -1 );
     $tests->{WEBCRAWLER}     = ( index( $ua, "webcrawler" ) != -1 );
     $tests->{WGET}           = ( index( $ua, "wget" ) != -1 );
+    $tests->{YANDEX}         = ( index( $ua, "yandexbot" ) != -1 );
     $tests->{YANDEXIMAGES}   = ( index( $ua, "yandeximages" ) != -1 );
 
     $tests->{ROBOT}
-        = (    $tests->{ALTAVISTA}
+        = (    $tests->{AHREFS}
+            || $tests->{ALTAVISTA}
             || $tests->{ASKJEEVES}
             || $tests->{BAIDU}
             || $tests->{FACEBOOK}
@@ -807,6 +824,7 @@ sub _robot_tests {
             || $tests->{WEBCRAWLER}
             || $tests->{WGET}
             || $tests->{YAHOO}
+            || $tests->{YANDEX}
             || $tests->{YANDEXIMAGES} )
         || index( $ua, "agent" ) != -1
         || index( $ua, "bot" ) != -1
@@ -989,6 +1007,7 @@ sub _os_tests {
             && !$tests->{ANDROID}
             && index( $ua, "fennec" ) == -1 );
 
+    $tests->{BB10} = ( index( $ua, "bb10" ) != -1 );
     $tests->{RIMTABLETOS} = ( index( $ua, "rim tablet os" ) != -1 );
 
     $tests->{PS3GAMEOS} = $tests->{PS3} && $tests->{NETFRONT};
@@ -1092,6 +1111,7 @@ sub os_string {
     return 'Linux'                       if $self->linux;
     return 'Unix'                        if $self->unix;
     return 'Firefox OS'                  if $self->firefoxos;
+    return 'BlackBerry 10'               if $self->bb10;
     return 'RIM Tablet OS'               if $self->rimtabletos;
     return 'Playstation 3 GameOS'        if $self->ps3gameos;
     return 'Playstation Portable GameOS' if $self->pspgameos;
@@ -1489,7 +1509,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.67
+version 1.69
 
 =head1 SYNOPSIS
 
@@ -1703,6 +1723,8 @@ mac68k macppc macosx ios
 
 =head2 os2()
 
+=head2 bb10()
+
 =head2 rimtabletos()
 
 =head2 unix()
@@ -1731,7 +1753,7 @@ compatibility with the L<HTTP::Headers::UserAgent> module.
   Win95, Win98, WinNT, Win2K, WinXP, Win2k3, WinVista, Win7, Win8,
   Win8.1, Windows Phone, Mac, Mac OS X, iOS, Win3x, OS2, Unix, Linux,
   Firefox OS, Playstation 3 GameOS, Playstation Portable GameOS,
-  RIM Tablet OS
+  RIM Tablet OS, BlackBerry 10
 
 =head1 Detecting Browser Vendor
 
@@ -1874,6 +1896,8 @@ automated Web client.
 The following additional methods are available, each returning a true or false
 value. This is by no means a complete list of robots that exist on the Web.
 
+=head3 ahrefs
+
 =head3 altavista
 
 =head3 askjeeves
@@ -1912,6 +1936,10 @@ value. This is by no means a complete list of robots that exist on the Web.
 
 =head3 yahoo
 
+=head3 yandex
+
+=head3 yandeximages
+
 =head1 CREDITS
 
 Lee Semel, lee@semel.net (Original Author)
@@ -2002,6 +2030,8 @@ David Ihnen
 
 Hao Wu
 
+Perlover
+
 =head1 TO DO
 
 The C<_engine()> method currently only handles Gecko and Trident.  It needs to
